.. _development:

===========
Development
===========

This chapter introduces advanced topics on modeling with AMS.
It aims to give an in-depth explanation of flexible dispatch mdoeling
framework and the interoperation with dynamic simulation.

.. toctree::
    :maxdepth: 2

    system
    model
    routine
    example
